@@ -28,7 +28,13 @@ class ExampleMenuProvider(GObject.GObject, Nautilus.MenuProvider):
     METHOD_HANDLER_TEMPLATE = '''
 \tdef {}(self, menu, files):
 \t\tfilenames = [unquote(subFile.get_uri()[7:]) for subFile in files]
-\t\t{}.{}(filenames)
+\t\t{}.{}({})
+
+'''
+
+    COMMAND_HANDLER_TEMPLATE = '''
+\tdef {}(self, menu, files):
+\t\tos.system('{}')
 
 '''
 
