@@ -6,8 +6,12 @@ sys.path.append(file_dir)
 sys.path.append(os.path.join(file_dir, 'windows'))
 sys.path.append(os.path.join(file_dir, 'linux'))
 
-from linux import linux_menus
-from windows import windows_menus
+if platform.system() == 'Linux':
+    from linux import linux_menus
+    linux_menus.NautilusMenu(self.name, self.sub_items, self.type).compile()
+if platform.system() == 'Windows':
+    from windows import windows_menus
+    windows_menus.RegistryMenu(self.name, self.sub_items, self.type).compile()
 
 
 import inspect
